@@ -1,13 +1,10 @@
 #-*- coding: utf-8 -*-
 
 import itertools as it, operator as op, functools as ft
-from urllib import urlencode
 from mimetypes import guess_type
-from time import time
 from collections import Mapping, OrderedDict
-from datetime import datetime, timedelta
 import os, sys, io, re, types, logging
-import urllib, urlparse, json, hashlib
+import urllib, hashlib
 
 from OpenSSL import crypto
 from zope.interface import implements
@@ -348,7 +345,7 @@ def join(*path_nodes):
 	return path
 
 
-class txU1API(object):
+class txU1(object):
 	'U1 API client.'
 
 	# api_url_content is a temporary caveat, described in API docs:
@@ -429,7 +426,7 @@ class txU1API(object):
 					if isinstance(data, types.StringTypes): data = io.BytesIO(data)
 				elif encode == 'form':
 					req_headers['Content-Type'] = 'application/x-www-form-urlencoded'
-					data = io.BytesIO(urlencode(data))
+					data = io.BytesIO(urllib.urlencode(data))
 				elif encode == 'json':
 					req_headers['Content-Type'] = 'application/json'
 					data = io.BytesIO(json.dumps(data))
@@ -677,8 +674,8 @@ if __name__ == '__main__':
 	logging.basicConfig(level=logging.DEBUG)
 	twisted_log.PythonLoggingObserver().start()
 
-	req_pool_optz = txU1API.request_pool_options.copy()
-	api = txU1API(debug_requests=True, request_pool_options=req_pool_optz)
+	req_pool_optz = txU1.request_pool_options.copy()
+	api = txU1(debug_requests=True, request_pool_options=req_pool_optz)
 
 	@defer.inlineCallbacks
 	def test():
